"""
Python mapping for the DictionaryServices framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""
import sys
import warnings

import CoreServices
import objc

warnings.warn(
    "pyobjc-framework-DictionaryServices is deprecated, use 'import CoreServices' instead",
    DeprecationWarning,
)

sys.modules["DictionaryServices"] = mod = objc.ObjCLazyModule(
    "DictionaryServices",
    "com.apple.CoreServices",
    objc.pathForFramework("/System/Library/Frameworks/CoreServices.framework"),
    None,
    None,
    {
        "__doc__": __doc__,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
        "objc": objc,
    },
    (CoreServices,),
)



import warnings

from PyObjCTools.TestSupport import TestCase, os_release, skipUnless

with warnings.catch_warnings():
    warnings.filterwarnings("ignore")
    import DictionaryServices


class TestDictionaryServices(TestCase):
    def testClasses(self):
        self.assertIsCFType(DictionaryServices.DCSDictionaryRef)

    @skipUnless(
        os_release().rsplit(".", 1)[0] not in ("10.12", "10.13"), "buggy OS release"
    )
    def testFunctions(self):
        txt = "the hello world program"
        r = DictionaryServices.DCSGetTermRangeInString(None, txt, 5)
        self.assertIsInstance(r, DictionaryServices.CFRange)
        self.assertEqual(r, (4, 5))

        r = DictionaryServices.DCSCopyTextDefinition(None, txt, r)
        self.assertIsInstance(r, (str, type(None)))

        v = DictionaryServices.DCSDictionaryGetTypeID()
        self.assertIsInstance(v, int)


class TestCallableMetadata(TestCase):
    def test_callable_metadata_is_sane(self):
        self.assertCallableMetadataIsSane(DictionaryServices)



"""
Deprecated wrappers for the "DictionaryServices" framework on macOS 10.5 or later.

Use package "CoreServices" instead.
"""
from pyobjc_setup import setup

VERSION = "9.1b1"

setup(
    name="pyobjc-framework-DictionaryServices",
    description="Wrappers for the framework DictionaryServices on macOS",
    min_os_level="10.5",
    packages=["DictionaryServices"],
    version=VERSION,
    install_requires=[
        "pyobjc-core>=" + VERSION,
        "pyobjc-framework-CoreServices>=" + VERSION,
    ],
    long_description=__doc__,
)
